==> models_weebi-1.0.22.tar.gz: lib/src/extensions/ticket_cl_stock.dart <==
// * WIP - might still need adjustments from yobi
import 'package:models_weebi/src/closings/closing_stock_product.dart';
import 'package:models_weebi/src/closings/closing_stock_shop/closing_stock_shop_product.dart';
import 'package:models_weebi/src/common/ticket_type.dart';
import 'package:models_weebi/src/models/ticket_weebi.dart';

extension ProductClosingBoyFeelsGoodAfterGulpingTBoneSteak on TicketWeebi {
  void incrementMyClosingStockHerder(List<ClosingStockProduct> stockProducts) {
    // * handling milk business exception
    // le lait n'est pas 'sorti' dans yobi, pourtant en pratique vendu
    // et réinitialisé tous les mois donc on adapte le calcul et l'affichage du lait
    if (this.ticketType == TicketType.spendDeferred &&
        this.items.any((i) => i.article.productId != 6) == false) {
      for (final item in items) {
        var cStockProduct =
            stockProducts.firstWhere((cSP) => cSP.id == item.article.productId);
        for (var cArticle in cStockProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            cArticle.quantityIn += item.quantity;
            cArticle.quantityOut += item.quantity;
            cArticle.finalQtCl += item.quantity;
          }
        }
      }
    } else {
      // * standard
      for (final item in items) {
        final cStockProduct = stockProducts.firstWhere(
            (e) => e.id == item.article.productId,
            orElse: () =>
                throw 'error stockProducts does not find productId match on : \nitem.article.productId${item.article.productId} ${item.article.productId.runtimeType}');
        for (final cArticle in cStockProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            // * if herder stock then opposite from shop stock
            // * herders might one day buy & sell same product
            if (ticketType.isHerderInput) {
              // blw allows us to reconcile stock
              cArticle.quantityIn += item.quantity;
              cArticle.finalQtCl += item.quantity;
              // product
              cStockProduct.finalQtCl += (item.quantity * cArticle.weight);
            } else {
              cArticle.quantityOut += item.quantity;
              cArticle.finalQtCl -= item.quantity;
              // product
              cStockProduct.finalQtCl -=
                  (item.quantity * cArticle.weight); // same
            }
          }
        }
      }
    }
  }

  void incrementMyClosingStock(List<ClosingStockProduct> stockProducts) {
    // * handling milk business exception
    // le lait n'est pas 'sorti' dans yobi, pourtant en pratique vendu
    // et réinitialisé tous les mois donc on adapte le calcul et l'affichage du lait
    if (this.ticketType == TicketType.spendDeferred &&
        this.items.any((element) => element.article.productId != 6) == false) {
      for (final item in items) {
        final cStockProduct = stockProducts
            .firstWhere((element) => element.id == item.article.productId);
        for (final cArticle in cStockProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            cArticle.quantityIn += item.quantity;
            cArticle.quantityOut += item.quantity;
            cArticle.finalQtCl += item.quantity;
          }
        }
      }
    } else {
      // * standard
      for (final item in items) {
        final cStockProduct = stockProducts.firstWhere(
            (element) => element.id == item.article.productId, orElse: () {
          throw 'error stockProducts does not find match productId on : \n${item.article.toJson()}';
        });
        for (final cArticle in cStockProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            // * if herder stock then opposite from shop stock
            // * herders might one day buy & sell same product
            if (ticketType.isShopInput) {
              cArticle.finalQtCl += item.quantity;
              cArticle.quantityIn += item.quantity;
              // product
              cStockProduct.finalQtCl += (item.quantity *
                  cArticle.weight); // allows us to reconcile stock
            } else {
              cArticle.finalQtCl -= item.quantity;
              cArticle.quantityOut += item.quantity;
              // product
              cStockProduct.finalQtCl -=
                  (item.quantity * cArticle.weight); // same
            }
          }
        }
      }
    }
  }

  void incrementClosingStockShop(
      List<ClosingStockShopProduct> clStockShopProducts) {
    // * handling milk business exception
    // le lait n'est pas 'sorti' dans yobi, pourtant en pratique vendu
    // et réinitialisé tous les mois donc on adapte le calcul et l'affichage du lait
    if (ticketType == TicketType.spendDeferred &&
        items.any((element) => element.article.productId != 6) == false) {
      for (final item in items) {
        final clStockShopProduct = clStockShopProducts.firstWhere(
            (element) => element.id == item.article.productId, orElse: () {
          throw 'error stockShopProducts milk does not find match productId on : \n${item.article.toJson()}';
        });
        for (final cArticle in clStockShopProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            // distinction if (ticketType.isShopInput) pas pertinente on sait que c'est lait entrée
            // if (ticketType.isShopInput) {
            cArticle.quantityIn += item.quantity;
            cArticle.quantityOut += item.quantity;
            // } else {
            //   cArticle.finalQuantity -= item.quantity;
            //   cArticle.quantityOut += item.quantity;
            // }
          }
        }
      }
    } else {
      for (final item in items) {
        final stockShopProduct = clStockShopProducts
            .firstWhere((c) => c.id == item.article.productId, orElse: () {
          throw 'error stockShopProducts does not find match productId on : \n${item.article.toJson()}';
        });
        for (final cArticle in stockShopProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            // distinction très importante, le produit peut être une entrée ou une sortie de stock du magasin
            if (ticketType.isShopInput) {
              cArticle.finalQtCl += item.quantity;
              cArticle.quantityIn += item.quantity;
              stockShopProduct.finalQtCl += (item.quantity *
                  cArticle.weight); // allows us to reconcile stock
            } else {
              cArticle.finalQtCl -= item.quantity;
              cArticle.quantityOut += item.quantity;
              stockShopProduct.finalQtCl -=
                  (item.quantity * cArticle.weight); // same
            }
          }
        }
      }
    }
  }
}

==> models_weebi-1.1.1.tar.gz: lib/src/extensions/ticket_cl_stock.dart <==
// * WIP - might still need adjustments from yobi
import 'package:models_weebi/src/closings/closing_stock_product.dart';
import 'package:models_weebi/src/closings/closing_stock_shop/closing_stock_shop_product.dart';
import 'package:models_weebi/src/common/ticket_type.dart';
import 'package:models_weebi/src/models/ticket_weebi.dart';

extension ProductClosingBoyFeelsGoodAfterGulpingTBoneSteak on TicketWeebi {
  void incrementMyClosingStockHerder(List<ClosingStockProduct> stockProducts) {
    // * handling milk business exception
    // le lait n'est pas 'sorti' dans yobi, pourtant en pratique vendu
    // et réinitialisé tous les mois donc on adapte le calcul et l'affichage du lait
    if (ticketType == TicketType.spendDeferred &&
        items.any((i) => i.article.productId != 6) == false) {
      for (final item in items) {
        var cStockProduct =
            stockProducts.firstWhere((cSP) => cSP.id == item.article.productId);
        for (var cArticle in cStockProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            cArticle.quantityIn += item.quantity;
            cArticle.quantityOut += item.quantity;
            cArticle.finalQtCl += item.quantity;
          }
        }
      }
    } else {
      // * standard
      for (final item in items) {
        final cStockProduct = stockProducts.firstWhere(
            (e) => e.id == item.article.productId,
            orElse: () =>
                throw 'error stockProducts does not find productId match on : \nitem.article.productId${item.article.productId} ${item.article.productId.runtimeType}');
        for (final cArticle in cStockProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            // * if herder stock then opposite from shop stock
            // * herders might one day buy & sell same product
            if (ticketType.isHerderInput) {
              // blw allows us to reconcile stock
              cArticle.quantityIn += item.quantity;
              cArticle.finalQtCl += item.quantity;
              // product
              cStockProduct.finalQtCl += (item.quantity * cArticle.weight);
            } else {
              cArticle.quantityOut += item.quantity;
              cArticle.finalQtCl -= item.quantity;
              // product
              cStockProduct.finalQtCl -=
                  (item.quantity * cArticle.weight); // same
            }
          }
        }
      }
    }
  }

  void incrementMyClosingStock(List<ClosingStockProduct> stockProducts) {
    // * handling milk business exception
    // le lait n'est pas 'sorti' dans yobi, pourtant en pratique vendu
    // et réinitialisé tous les mois donc on adapte le calcul et l'affichage du lait
    if (ticketType == TicketType.spendDeferred &&
        items.any((element) => element.article.productId != 6) == false) {
      for (final item in items) {
        final cStockProduct = stockProducts
            .firstWhere((element) => element.id == item.article.productId);
        for (final cArticle in cStockProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            cArticle.quantityIn += item.quantity;
            cArticle.quantityOut += item.quantity;
            cArticle.finalQtCl += item.quantity;
          }
        }
      }
    } else {
      // * standard
      for (final item in items) {
        final cStockProduct = stockProducts.firstWhere(
            (element) => element.id == item.article.productId, orElse: () {
          throw 'error stockProducts does not find match productId on : \n${item.article.toJson()}';
        });
        for (final cArticle in cStockProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            // * if herder stock then opposite from shop stock
            // * herders might one day buy & sell same product
            if (ticketType.isShopInput) {
              cArticle.finalQtCl += item.quantity;
              cArticle.quantityIn += item.quantity;
              // product
              cStockProduct.finalQtCl += (item.quantity *
                  cArticle.weight); // allows us to reconcile stock
            } else {
              cArticle.finalQtCl -= item.quantity;
              cArticle.quantityOut += item.quantity;
              // product
              cStockProduct.finalQtCl -=
                  (item.quantity * cArticle.weight); // same
            }
          }
        }
      }
    }
  }

  void incrementClosingStockShop(
      List<ClosingStockShopProduct> clStockShopProducts) {
    // * handling milk business exception
    // le lait n'est pas 'sorti' dans yobi, pourtant en pratique vendu
    // et réinitialisé tous les mois donc on adapte le calcul et l'affichage du lait
    if (ticketType == TicketType.spendDeferred &&
        items.any((element) => element.article.productId != 6) == false) {
      for (final item in items) {
        final clStockShopProduct = clStockShopProducts.firstWhere(
            (element) => element.id == item.article.productId, orElse: () {
          throw 'error stockShopProducts milk does not find match productId on : \n${item.article.toJson()}';
        });
        for (final cArticle in clStockShopProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            // distinction if (ticketType.isShopInput) pas pertinente on sait que c'est lait entrée
            // if (ticketType.isShopInput) {
            cArticle.quantityIn += item.quantity;
            cArticle.quantityOut += item.quantity;
            // } else {
            //   cArticle.finalQuantity -= item.quantity;
            //   cArticle.quantityOut += item.quantity;
            // }
          }
        }
      }
    } else {
      for (final item in items) {
        final stockShopProduct = clStockShopProducts
            .firstWhere((c) => c.id == item.article.productId, orElse: () {
          throw 'error stockShopProducts does not find match productId on : \n${item.article.toJson()}';
        });
        for (final cArticle in stockShopProduct.articles) {
          if (cArticle.productId == item.article.productId &&
              cArticle.id == item.article.id) {
            // distinction très importante, le produit peut être une entrée ou une sortie de stock du magasin
            if (ticketType.isShopInput) {
              cArticle.finalQtCl += item.quantity;
              cArticle.quantityIn += item.quantity;
              stockShopProduct.finalQtCl += (item.quantity *
                  cArticle.weight); // allows us to reconcile stock
            } else {
              cArticle.finalQtCl -= item.quantity;
              cArticle.quantityOut += item.quantity;
              stockShopProduct.finalQtCl -=
                  (item.quantity * cArticle.weight); // same
            }
          }
        }
      }
    }
  }
}
